bandsplot — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# bandsplot

pyprocar.scripts.bandsplot(code: str, dirname: str, mode: str = 'plain', spins: List[int] | None = None, atoms: List[int] | None = None, orbitals: List[int] | None = None, items: dict = {}, fermi: float | None = None, fermi_shift: float = 0, interpolation_factor: int = 1, interpolation_type: str = 'cubic', projection_mask: ndarray | None = None, kticks=None, knames=None, kdirect: bool = True, elimit: List[float] | None = None, ax: Axes | None = None, show: bool = True, savefig: str | None = None, print_plot_opts: bool = False, export_data_file: str | None = None, export_append_mode: bool = True, **kwargs)

  A function to plot the band structutre

  Parameters:

    - code (str, optional) – String to of the code used, by default “vasp”

    - dirname (str, optional) – The directory name of the calculation, by default None

    - mode (str, optional) – Sting for the mode of the calculation, by default “plain”

    - spins (List[int], optional) – A list of spins, by default None

    - atoms (List[int], optional) – A list of atoms, by default None

    - orbitals (List[int], optional) – A list of orbitals, by default None

    - items (dict, optional) – A dictionary where the keys are the atoms and the values a list of orbitals, by default {}

    - fermi (float, optional) – Float for the fermi energy, by default None. By default the fermi energy will be shifted by the fermi value that is found in the directory. For band structure calculations, due to convergence issues, this fermi energy might not be accurate. If so add the fermi energy from the self-consistent calculation.

    - fermi_shift (float, optional) – Float to shift the fermi energy, by default 0.

    - interpolation_factor (int, optional) – The interpolation_factor, by default 1

    - interpolation_type (str, optional) – The interpolation type, by default “cubic”

    - projection_mask (np.ndarray, optional) – A custom projection mask, by default None

    - kticks (_type_, optional) – A list of kticks, by default None

    - knames (_type_, optional) – A list of kanems, by default None

    - elimit (List[float], optional) – A list of floats to decide the energy window, by default None

    - ax (plt.Axes, optional) – A matplotlib axes, by default None

    - show (bool, optional) – Boolean if to show the plot, by default True

    - savefig (str, optional) – String to save the plot, by default None

    - export_data_file (str, optional) – The file name to export the data to. If not provided the data will not be exported.

    - export_append_mode (bool, optional) – Boolean to append the mode to the file name. If not provided the data will be overwritten.

    - print_plot_opts (bool, optional) – Boolean to print the plotting options